include "src/hardware.inc"

global draw_bg, puthex, putnibble

SECTION "rom_bg", ROM0

; Background drawing ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

draw_bg:
  xor a
  ldh [rVBK],a  

  ; Fill CHR RAM
  ld hl,bggfx_chr
  ld de,CHRRAM2
  ld bc,16*96
  call memcpy

  ; Clear nametable
  ld h,0
  ld de,_SCRN0
  ld bc,32*16
  call memset

  ; Draw top of floor
  ld a,$0B
  ld hl,_SCRN0+32*16
  ld c,20
  call memset_tiny
  
  ; Draw bottom of floor
  ld a,$01
  ld hl,_SCRN0+32*17
  ld c,20
  call memset_tiny

  ; On GBC, draw sky and floor attributes
  ld a,[initial_a]
  cp $11
  jr nz,.not_gbc
    ldh [rVBK],a

    ; Palette 0: Sky and floor
    ld h,0
    ld de,_SCRN0
    ld bc,32*18
    call memset

    ; Replace first tile (sky) with a blank one
    xor a
    ldh [rVBK],a
    ld hl,CHRRAM2
    ld c,16
    call memset_tiny
  .not_gbc:

  ld hl,_SCRN0+32*12+1
  call bg_draw_one_block
  ld hl,_SCRN0+32*14+1
  call bg_draw_one_block
  ld hl,_SCRN0+32*12+17
  call bg_draw_one_block
  ld hl,_SCRN0+32*14+17
  call bg_draw_one_block

  ; Write initial A and B values
  ld hl,_SCRN0+32*0+16
  ld a,"A"
  ld [hl+],a
  ld a,":"
  ld [hl+],a
  ld a,[initial_a]
  call puthex
  ld hl,_SCRN0+32*1+16
  ld a,"B"
  ld [hl+],a
  ld a,":"
  ld [hl+],a
  ld a,[initial_b]
  call puthex
  ret

bg_draw_one_block:
  ld a,$0C
  ld [hl+],a
  inc a
  ld [hl-],a
  inc a
  set 5,l
  ld [hl+],a
  inc a
  ld [hl-],a

  ; If GBC, set the attributes as well
  ld a,[initial_a]
  cp $11
  jr nz,.not_gbc
    ldh [rVBK],a
    ld [hl+],a
    ld [hl-],a
    res 5,l
    ld [hl+],a
    ld [hl-],a
    xor a
    ldh [rVBK],a
  .not_gbc:
  ret

;;
; Writes two hex nibbles ("0123456789ABCDEF") to HL
puthex:
  push af
  swap a
  and $0F
  call putnibble
  pop af
  and $0F
putnibble:
  cp $0A
  jr c,.not_letter
  add ("A"-"9"-1)
.not_letter:
  add "0"
  ld [hl+],a
  ret

bggfx_chr: incbin "obj/gb/bggfx.chrgb"
