  IF  !DEF(GLOBAL_INC)
GLOBAL_INC SET 1

; This program contains one use of EQU to allocate local variables
; in RAM.  Other more experienced devs want to abolish allocation
; of variables using EQU.  Without EQU, I can't see how to make
; different subroutines share RAM for their local variables without
; using UNION.

; The person who suggested using UNION has not yet explained how to
; resolve its drawback that the declaration of local variables is
; separated from the subroutine's code.  Either you have to declare
; local variables for all subroutines in a program within one file:
;
; UNION
; draw_metasprite__basex: ds 1
; draw_metasprite__basey: ds 1
; draw_metasprite__width: ds 1
; draw_metasprite__height: ds 1
; NEXTU
; mul8__factor1: .ds 1
; mul8__factor2: .ds 1
; mul8__product: .ds 2
; ENDU
;
; Or you have to declare the local variables for every subroutine
; in a separate file:
;
; UNION
; INCLUDE "src/draw_sprite_vars.inc"
; NEXTU
; INCLUDE "src/mul8_vars.inc"
; ENDU
;
; The interim solution uses a single EQU to set up RSSET.
;
; RSSET hLocals
; Lbasex rb 1
; Lbasey rb 1
; Lwidth rb 1
; Lheight rb 1
;
; RSSET hLocals
; Lfactor1 rb 1
; Lfactor2 rb 1
; Lproduct rw 1
;
; Follow this thread:
; http://gbdev.gg8.se/forums/viewtopic.php?pid=3176#p3176
hLocals EQU $FF80
locals_size EQU 16

; Macro to define an RGB value for Game Boy Color

drgb: macro
  dw (\1 & $F80000) >> 19 | (\1 & $00F800) >> 6 | (\1 & $0000F8) << 7

  endm

  endc