include "src/hardware.inc"

REGION_UE = 1

; Instead of vectors, LR35902 has RSTs ("reset trampolines"?) spaced
; 8 bytes apart.  There are eight for short encodings of CALL with
; specific addresses ($C7, $CF, ..., $FF) and five for interrupt
; service routines (ISR).  Fill them with JPs to the actual handlers.
SECTION "rst00", ROM0[$0000]
  ret
SECTION "rst08", ROM0[$0008]
  ret
SECTION "rst10", ROM0[$0010]
  ret
SECTION "rst18", ROM0[$0018]
  ret
SECTION "rst20", ROM0[$0020]
  ret
SECTION "rst28", ROM0[$0028]
  ret
SECTION "rst30", ROM0[$0030]
  ret
SECTION "rst38", ROM0[$0038]
  ret
SECTION "rst40", ROM0[$0040]
  jp vblank_handler
SECTION "rst48", ROM0[$0048]
  jp stat_handler
SECTION "rst50", ROM0[$0050]
  jp timer_handler
SECTION "rst58", ROM0[$0058]
  jp serial_handler
SECTION "rst60", ROM0[$0060]
  jp joypad_handler

SECTION "header", ROM0[$0100]
  nop
  jp reset_handler

  ; The header is used by IPL to ensure that at least D7-D0
  ; and A5-A0 have a good connection before calling something
  ; in the game that might corrupt battery-backed save RAM.
  ; TODO: Figure out how much of this RGBFIX can fill in for me

  ; magiccookiedata: spells "Nintendo" when deinterleaved to tiles
  NINTENDO_LOGO

  ; 11-character title
  DB "HELLO"
  DS 6

  ; Serial code (is ADME Doom or Animal Crossing?)
  DS 4

  ; Execution mode (GBC runs in GBC mode if bit 7 is true)
  DB CART_COMPATIBLE_DMG_GBC

  ; $0144: Developer ID
  DB "OK"

  ; SGB mode
  DB $03

  ; Mapper
  DB CART_ROM

  ; $0148: ceil(log2(ROM size / 32768))
  DB CART_ROM_256K
  
  ; RAM size: log2(RAM size / 512)/2
  DB CART_RAM_NONE

  ; Region code
  DB REGION_UE

  ; Old hex developer ID: $33 means "see $0144"
  DB $33
  
  ; ROM version number
  DB $00

  ; Leave space for header checksum to be filled in by rgbfix
  DS 3

